#
# spec file for package python-quantum-blackbird
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packagename quantum-blackbird
%define skip_python2 1
%define skip_python36 1
Name:           python-quantum-blackbird
Version:        0.5.0
Release:        1.4
Summary:        Quantum assembly language for continuous-variable quantum computation
License:        Apache-2.0
URL:            https://github.com/XanaduAI/blackbird
Source:         https://github.com/XanaduAI/blackbird/archive/v%{version}.tar.gz#/blackbird-%{version}.tar.gz
BuildRequires:  %{python_module antlr4-python3-runtime >= 4.9.2}
BuildRequires:  %{python_module networkx}
BuildRequires:  %{python_module numpy >= 1.16}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sympy}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  uuid-devel
Requires:       python-antlr4-python3-runtime >= 4.9.2
Requires:       python-networkx
Requires:       python-numpy >= 1.16
Requires:       python-sympy
BuildArch:      noarch
%python_subpackages

%description
Blackbird is a quantum assembly language for continuous-variable quantum
computation, that can be used to program Xanadu's quantum photonics
hardware and Strawberry Fields simulator.

%prep
%autosetup -p1 -n blackbird-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Fix E: spurious-executable-perm of README.rst
chmod 644 README.rst

%check
# Broken tests with numpy 1.24 gh#XanaduAI/blackbird#54
donttest="scalar_array or test_array_variable_expression"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*egg-info
%{python_sitelib}/blackbird

%changelog
* Mon Mar  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable numpy 1.24 broken tests, gh#XanaduAI/blackbird#54
- Remove skip_32bit_divide_scalar_array_test.patch
- Remove fix-aarch64.patch
- Update to 0.5.0
  * Rebuilds the grammar using ANTLR v4.9.2 (#51)
  * Updates ANTLR v4.9.2 version on the compiling grammar section.  (#51)
- 0.4.0
  * Remove support for Python 3.5. (#38)
  * Add support for Python 3.8 and 3.9. (#40)
  * Add public method to retrieve Blackbird program variables via
    prog.variables. (#47)
  * Improve match_template to automatically return matched parameters
    with their array values, rather than their array names (p0, p1,
    etc.) (#47)
  * Remove p-type parameters from prog.parameters since they're only
    needed there internally and are otherwise stored in
    prog.variables. This also changes TDM programs to not be templates
    (prog.is_template now returns False).  (#47)
  * Fix bool or string objects in for-loop iterators not working
    correctly. (#41)
  * Update the NumPy scalar types in the Blackbird listener due to
    being deprecated in NumPy 1.20. (#43)
  * Add access to the symbolic expression used when creating a
    RegRefTransform, as a class attribute. (#46)
* Thu Jun 17 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add upstream patch to fix test on aarch64:
  * fix-aarch64.patch
* Wed May 12 2021 Matej Cepl <mcepl@suse.com>
- Add skip_32bit_divide_scalar_array_test.patch to skip the
  failing test on 32bit arch (gh#XanaduAI/blackbird#42).
* Mon Apr 26 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 0.3.0.
  * Arrays and variables now support being defined as parameters
    (using braces) in a Blackbird template.
  * Time-domain multiplexing programs are now supported, using the
    syntax type tdm (temporal_modes=3, copies=1).
  * For-loops are supported inside Blackbird scripts.
  * Keyword arguments are supported inside operations; for example,
    MeasureHomodyne(select=[0, 1]) or
    MeasureFock(dark_counts=[1, 0.5, 3]).
  * Indexing is supported inside both modes and arguments; for
    example, MZgate(list[2], list[0]) | [list[3], list[1]])).
    All indices allow expressions such as phases[-3 + 2*2].
  * Templates are no longer changed when calling them and replacing
    the parameters with actual values.
* Thu Sep  3 2020 andy great <andythe_great@pm.me>
- Update to version 0.2.4.
  * Updating antlr4-python3-runtime requirement to version 4.7.2.
* Tue Aug 11 2020 andy great <andythe_great@pm.me>
- Drop to version 0.2.1 from github release as it have test suite.
* Tue Aug  4 2020 andy great <andythe_great@pm.me>
- Initial package release.
